@@ -1,7 +1,8 @@
 from contextlib import closing
 import logging
 
-from ..util import properties
+from .. import backend
+from .._compat import properties
 from ..backend import KeyringBackend
 from ..credentials import SimpleCredential
 from ..errors import (
@@ -23,23 +24,26 @@ except AttributeError:
 log = logging.getLogger(__name__)
 
 
-class Keyring(KeyringBackend):
+class Keyring(backend.SchemeSelectable, KeyringBackend):
     """Secret Service Keyring"""
 
     appid = 'Python keyring library'
 
-    @properties.ClassProperty
-    @classmethod
-    def priority(cls):
+    @properties.classproperty
+    def priority(cls) -> int:
         with ExceptionRaisedContext() as exc:
             secretstorage.__name__
         if exc:
             raise RuntimeError("SecretStorage required")
-        if secretstorage.__version_tuple__[0] < 3:
-            raise RuntimeError("SecretStorage 3.0 or newer required")
+        if secretstorage.__version_tuple__ < (3, 2):
+            raise RuntimeError("SecretStorage 3.2 or newer required")
         try:
             with closing(secretstorage.dbus_init()) as connection:
-                list(secretstorage.get_all_collections(connection))
+                if not secretstorage.check_service_availability(connection):
+                    raise RuntimeError(
+                        "The Secret Service daemon is neither running nor "
+                        "activatable through D-Bus"
+                    )
         except exceptions.SecretStorageException as e:
             raise RuntimeError("Unable to initialize SecretService: %s" % e)
         return 5
@@ -73,7 +77,7 @@ class Keyring(KeyringBackend):
         """Get password of the username for the service"""
         collection = self.get_preferred_collection()
         with closing(collection.connection):
-            items = collection.search_items({"username": username, "service": service})
+            items = collection.search_items(self._query(service, username))
             for item in items:
                 self.unlock(item)
                 return item.get_secret().decode('utf-8')
@@ -81,11 +85,7 @@ class Keyring(KeyringBackend):
     def set_password(self, service, username, password):
         """Set password for the username of the service"""
         collection = self.get_preferred_collection()
-        attributes = {
-            "application": self.appid,
-            "service": service,
-            "username": username,
-        }
+        attributes = self._query(service, username, application=self.appid)
         label = "Password for '{}' on '{}'".format(username, service)
         with closing(collection.connection):
             collection.create_item(label, attributes, password, replace=True)
@@ -94,7 +94,7 @@ class Keyring(KeyringBackend):
         """Delete the stored password (only the first one)"""
         collection = self.get_preferred_collection()
         with closing(collection.connection):
-            items = collection.search_items({"username": username, "service": service})
+            items = collection.search_items(self._query(service, username))
             for item in items:
                 return item.delete()
         raise PasswordDeleteError("No such password!")
@@ -107,16 +107,13 @@ class Keyring(KeyringBackend):
         and return a SimpleCredential containing  the username and password
         Otherwise, it will return the first username and password combo that it finds.
         """
-
-        query = {"service": service}
-        if username:
-            query["username"] = username
-
+        scheme = self.schemes[self.scheme]
+        query = self._query(service, username)
         collection = self.get_preferred_collection()
 
         with closing(collection.connection):
             items = collection.search_items(query)
             for item in items:
                 self.unlock(item)
-                username = item.get_attributes().get("username")
+                username = item.get_attributes().get(scheme['username'])
                 return SimpleCredential(username, item.get_secret().decode('utf-8'))
