@@ -54,7 +54,7 @@ class DecodingCredential(dict):
         except UnicodeDecodeError:
             decoded_cred_utf8 = cred.decode('utf-8')
             log.warning(
-                "Retrieved an UTF-8 encoded credential. Please be aware that "
+                "Retrieved a UTF-8 encoded credential. Please be aware that "
                 "this library only writes credentials in UTF-16."
             )
             return decoded_cred_utf8
@@ -81,7 +81,7 @@ class WinVaultKeyring(KeyringBackend):
     persist = Persistence()
 
     @properties.classproperty
-    def priority(cls):
+    def priority(cls) -> int:
         """
         If available, the preferred backend on Windows.
         """
